Todo

Things to think about

  1. Remove helper/utility functions from the router module
  2. Figure out how to traverse the node tree to reconstruct dynamic segments like :id
  3. Think about how to attach metadata to routes, similar to Swagger/OpenAPI

Things to do

  1. Implement a describe function that annotates the last added route with a docstring
Search Document