Todo
Things to think about
- Remove helper/utility functions from the router module
- Figure out how to traverse the node tree to reconstruct dynamic segments like
:id - Think about how to attach metadata to routes, similar to Swagger/OpenAPI
Things to do
- Implement a
describefunction that annotates the last added route with a docstring